@@ -11,7 +11,7 @@ test_that("get_chunk_info works", {
                              index = c(8L, 18L, 26L)), row.names = c(NA, -3L), class = c("tbl_df",
                                                                                          "tbl", "data.frame"))
 
-  testthat::expect_equal(UNF::unf(output), UNF::unf(expected))
+  testthat::expect_equal(output,expected)
 
   testthat::expect_null(get_chunk_info(""))
 })
